PopupMessage class

Inheritance
Available extensions

Constructors

PopupMessage({Key? key, required Widget child, required Widget content, EdgeInsets padding = const EdgeInsets.all(10), EdgeInsets margin = const EdgeInsets.all(5), Color bgColor = Colors.white, Size size = const Size(7, 7), double maxWidth = 200, double radius = 4, Color barrierColor = const Color(0x05000000), FutureOr<bool> onPreShow()?})
const

Properties

barrierColor → Color
遮罩背景色
final
bgColor → Color
弹框背景色
final
child → Widget
默认显示内容
final
content → Widget
弹框显示内容
final
hashCode → int
The hash code for this object.
no setterinherited
heightFull → SpinnerPopScope

Available on Widget, provided by the SpinnerPopScopeExt extension

显示占满全部空间
no setter
heightPart → SpinnerPopScope

Available on Widget, provided by the SpinnerPopScopeExt extension

显示占据部分高度
no setter
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin → EdgeInsets
弹框与child内容之间的距离
final
maxWidth → double
限制弹框最大显示宽度
final
onPreShow → FutureOr<bool> Function()?
设置是否需要显示弹窗内容
final
padding → EdgeInsets
弹框內间距
final
radius → double
弹框圆角
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → Size
弹框三角大小
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<PopupMessage>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
height([double scale = 0.7]) → SpinnerPopScope

Available on Widget, provided by the SpinnerPopScopeExt extension

快速构建 PopupBtns builder 数组集
hideKeyboard(BuildContext context) → Widget

Available on Widget, provided by the HideKeyboardX extension

添加键盘关闭事件
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited